@@ -2,7 +2,7 @@ import enum
 import re
 from typing import Any
 
-ENUM_NAME_REGEX = re.compile("[_a-zA-Z0-9]+")
+ENUM_NAME_REGEX = re.compile(r"[_a-zA-Z0-9]+")
 
 
 def generate_python_enum(name: str, options: list[Any]) -> type[enum.Enum]:
