@@ -3,6 +3,7 @@ from infrahub.dependencies.interface import DependencyBuilder, DependencyBuilder
 
 from .attribute_choices import SchemaAttributeChoicesConstraintDependency
 from .attribute_enum import SchemaAttributeEnumConstraintDependency
+from .attribute_kind import SchemaAttributeKindConstraintDependency
 from .attribute_length import SchemaAttributLengthConstraintDependency
 from .attribute_optional import SchemaAttributeOptionalConstraintDependency
 from .attribute_regex import SchemaAttributeRegexConstraintDependency
@@ -13,6 +14,7 @@ from .node_attribute import SchemaNodeAttributeAddConstraintDependency
 from .node_relationship import SchemaNodeRelationshipAddConstraintDependency
 from .relationship_count import SchemaRelationshipCountConstraintDependency
 from .relationship_optional import SchemaRelationshipOptionalConstraintDependency
+from .relationship_peer import SchemaRelationshipPeerParentConstraintDependency
 from .uniqueness import SchemaUniquenessConstraintDependency
 
 
@@ -32,8 +34,10 @@ class AggregatedSchemaConstraintsDependency(DependencyBuilder[AggregatedConstrai
                 SchemaAttributeChoicesConstraintDependency.build(context=context),
                 SchemaAttributeEnumConstraintDependency.build(context=context),
                 SchemaAttributLengthConstraintDependency.build(context=context),
+                SchemaAttributeKindConstraintDependency.build(context=context),
                 SchemaNodeAttributeAddConstraintDependency.build(context=context),
                 SchemaNodeRelationshipAddConstraintDependency.build(context=context),
+                SchemaRelationshipPeerParentConstraintDependency.build(context=context),
             ],
             db=context.db,
             branch=context.branch,
