@@ -1,11 +1,18 @@
+from __future__ import annotations
+
+import asyncio
+from typing import TYPE_CHECKING, Any
+
 from infrahub_sdk.exceptions import ModuleImportError
 from infrahub_sdk.node import InfrahubNode
 from infrahub_sdk.protocols import CoreGeneratorInstance
 from infrahub_sdk.schema.repository import InfrahubGeneratorDefinitionConfig
-from prefect import flow, task
+from prefect import State, flow, task
 from prefect.cache_policies import NONE
+from prefect.states import Completed, Failed
 
 from infrahub import lock
+from infrahub.context import InfrahubContext  # noqa: TC001 needed for prefect flow
 from infrahub.core.constants import GeneratorInstanceStatus, InfrahubKind
 from infrahub.generators.models import (
     ProposedChangeGeneratorDefinition,
@@ -14,19 +21,20 @@ from infrahub.generators.models import (
 )
 from infrahub.git.base import extract_repo_file_information
 from infrahub.git.repository import get_initialized_repo
-from infrahub.services import InfrahubServices, services
+from infrahub.services import InfrahubServices  # noqa: TC001 needed for prefect flow
 from infrahub.workflows.catalogue import REQUEST_GENERATOR_DEFINITION_RUN, REQUEST_GENERATOR_RUN
-from infrahub.workflows.utils import add_branch_tag
+from infrahub.workflows.utils import add_tags
+
+if TYPE_CHECKING:
+    from collections.abc import Coroutine
 
 
 @flow(
     name="generator-run",
-    flow_run_name="Run generator {model.generator_definition.definition_name} for {model.target_name}",
+    flow_run_name="Run generator {model.generator_definition.definition_name}",
 )
-async def run_generator(model: RequestGeneratorRun) -> None:
-    service = services.service
-
-    await add_branch_tag(branch_name=model.branch_name)
+async def run_generator(model: RequestGeneratorRun, service: InfrahubServices) -> None:
+    await add_tags(branches=[model.branch_name], nodes=[model.target_id])
 
     repository = await get_initialized_repo(
         repository_id=model.repository_id,
@@ -70,15 +78,15 @@ async def run_generator(model: RequestGeneratorRun) -> None:
         )
         await generator.run(identifier=generator_definition.name)
         generator_instance.status.value = GeneratorInstanceStatus.READY.value
-    except ModuleImportError:
-        generator_instance.status.value = GeneratorInstanceStatus.ERROR.value
-    except Exception:  # pylint: disable=broad-exception-caught
+    except (ModuleImportError, Exception):  # pylint: disable=broad-exception-caught
         generator_instance.status.value = GeneratorInstanceStatus.ERROR.value
+        await generator_instance.update(do_full_update=True)
+        raise
 
     await generator_instance.update(do_full_update=True)
 
 
-@task(name="generator-define-instance", task_run_name="Define Instance", cache_policy=NONE)
+@task(name="generator-define-instance", task_run_name="Define Instance", cache_policy=NONE)  # type: ignore[arg-type]
 async def _define_instance(model: RequestGeneratorRun, service: InfrahubServices) -> CoreGeneratorInstance:
     if model.generator_instance:
         instance = await service.client.get(
@@ -116,11 +124,9 @@ async def _define_instance(model: RequestGeneratorRun, service: InfrahubServices
     return instance
 
 
-@flow(name="generator_definition_run", flow_run_name="Run all generators")
-async def run_generator_definition(branch: str) -> None:
-    service = services.service
-
-    await add_branch_tag(branch_name=branch)
+@flow(name="generator-definition-run", flow_run_name="Run all generators")
+async def run_generator_definition(branch: str, context: InfrahubContext, service: InfrahubServices) -> None:
+    await add_tags(branches=[branch])
 
     generators = await service.client.filters(
         kind=InfrahubKind.GENERATORDEFINITION, prefetch_relationships=True, populate_store=True, branch=branch
@@ -144,17 +150,19 @@ async def run_generator_definition(branch: str) -> None:
 
     for generator_definition in generator_definitions:
         model = RequestGeneratorDefinitionRun(branch=branch, generator_definition=generator_definition)
-        await service.workflow.submit_workflow(workflow=REQUEST_GENERATOR_DEFINITION_RUN, parameters={"model": model})
+        await service.workflow.submit_workflow(
+            workflow=REQUEST_GENERATOR_DEFINITION_RUN, context=context, parameters={"model": model}
+        )
 
 
 @flow(
-    name="request_generator_definition_run",
+    name="request-generator-definition-run",
     flow_run_name="Execute generator {model.generator_definition.definition_name}",
 )
-async def request_generator_definition_run(model: RequestGeneratorDefinitionRun) -> None:
-    service = services.service
-
-    await add_branch_tag(branch_name=model.branch)
+async def request_generator_definition_run(
+    model: RequestGeneratorDefinitionRun, context: InfrahubContext, service: InfrahubServices
+) -> State[Any]:
+    await add_tags(branches=[model.branch], nodes=[model.generator_definition.definition_id])
 
     group = await service.client.get(
         kind=InfrahubKind.GENERICGROUP,
@@ -189,8 +197,13 @@ async def request_generator_definition_run(model: RequestGeneratorDefinitionRun)
             raise_when_missing=True,
         )
 
+    tasks: list[Coroutine[Any, Any, Any]] = []
     for relationship in group.members.peers:
         member = relationship.peer
+
+        if model.target_members and member.id not in model.target_members:
+            continue
+
         generator_instance = instance_by_member.get(member.id)
         request_generator_run_model = RequestGeneratorRun(
             generator_definition=model.generator_definition,
@@ -201,10 +214,18 @@ async def request_generator_definition_run(model: RequestGeneratorDefinitionRun)
             repository_kind=repository.typename,
             branch_name=model.branch,
             query=model.generator_definition.query_name,
-            variables=member.extract(params=model.generator_definition.parameters),
+            variables=await member.extract(params=model.generator_definition.parameters),
             target_id=member.id,
             target_name=member.display_label,
         )
-        await service.workflow.submit_workflow(
-            workflow=REQUEST_GENERATOR_RUN, parameters={"model": request_generator_run_model}
+        tasks.append(
+            service.workflow.execute_workflow(
+                workflow=REQUEST_GENERATOR_RUN, context=context, parameters={"model": request_generator_run_model}
+            )
         )
+
+    try:
+        await asyncio.gather(*tasks)
+        return Completed(message=f"Successfully run {len(tasks)} generators")
+    except Exception as exc:
+        return Failed(message="One or more generators failed", error=exc)
