@@ -6,7 +6,7 @@ import graphene
 from infrahub.core.enums import generate_python_enum
 from infrahub.core.schema import AttributeSchema, MainSchemaTypes
 
-ENUM_NAME_REGEX = re.compile("[_a-zA-Z0-9]+")
+ENUM_NAME_REGEX = re.compile(r"[_a-zA-Z0-9]+")
 
 
 def get_enum_attribute_type_name(node_schema: MainSchemaTypes, attr_schema: AttributeSchema) -> str:
