@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from graphene import ID, Field, List, String
+from graphene import ID, Field, List, NonNull, String
 from infrahub_sdk.utils import extract_fields_first_node
 
 from infrahub.graphql.types import BranchType
@@ -12,17 +12,19 @@ if TYPE_CHECKING:
 
 
 async def branch_resolver(
-    root: dict,  # pylint: disable=unused-argument
+    root: dict,  # noqa: ARG001
     info: GraphQLResolveInfo,
     **kwargs: Any,
 ) -> list[dict[str, Any]]:
     fields = await extract_fields_first_node(info)
-    return await BranchType.get_list(context=info.context, fields=fields, **kwargs)
+    return await BranchType.get_list(graphql_context=info.context, fields=fields, **kwargs)
 
 
 BranchQueryList = Field(
-    List(BranchType),
+    List(of_type=NonNull(BranchType)),
     ids=List(ID),
     name=String(),
+    description="Retrieve information about active branches.",
     resolver=branch_resolver,
+    required=True,
 )
