@@ -1,9 +1,15 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import redis.asyncio as redis
 
 from infrahub import config
-from infrahub.message_bus.types import KVTTL
 from infrahub.services.adapters.cache import InfrahubCache
 
+if TYPE_CHECKING:
+    from infrahub.message_bus.types import KVTTL
+
 
 class RedisCache(InfrahubCache):
     def __init__(self) -> None:
@@ -44,3 +50,7 @@ class RedisCache(InfrahubCache):
 
     async def set(self, key: str, value: str, expires: KVTTL | None = None, not_exists: bool = False) -> bool | None:
         return await self.connection.set(name=key, value=value, ex=expires.value if expires else None, nx=not_exists)
+
+    @classmethod
+    async def new(cls) -> RedisCache:
+        return cls()
